@@ -22,7 +22,7 @@ Author: Aidan Jungo
 
 """
 
-from cpacspy.cpacsfunctions import (get_value_or_default, get_tigl_configuration)
+from cpacspy.cpacsfunctions import get_value_or_default, get_tigl_configuration
 from cpacspy.utils import REF_XPATH
 
 
@@ -41,11 +41,11 @@ class Aircraft:
         self.tigl = tigl
 
         # Reference values
-        self.ref_lenght = get_value_or_default(self.tixi, REF_XPATH + '/length', 1)
-        self.ref_area = get_value_or_default(self.tixi, REF_XPATH + '/area', 1)
-        self.ref_point_x = get_value_or_default(self.tixi, REF_XPATH + '/point/x', 0)
-        self.ref_point_y = get_value_or_default(self.tixi, REF_XPATH + '/point/y', 0)
-        self.ref_point_z = get_value_or_default(self.tixi, REF_XPATH + '/point/z', 0)
+        self.ref_lenght = get_value_or_default(self.tixi, REF_XPATH + "/length", 1)
+        self.ref_area = get_value_or_default(self.tixi, REF_XPATH + "/area", 1)
+        self.ref_point_x = get_value_or_default(self.tixi, REF_XPATH + "/point/x", 0)
+        self.ref_point_y = get_value_or_default(self.tixi, REF_XPATH + "/point/y", 0)
+        self.ref_point_z = get_value_or_default(self.tixi, REF_XPATH + "/point/z", 0)
 
         # Aircraft specific values (extract with TiGL)
         self.configuration = get_tigl_configuration(self.tigl)
@@ -109,17 +109,18 @@ class Aircraft:
     def __str__(self):
 
         text_line = []
-        text_line.append('\nAircraft data -------------------------------------------------------')
-        text_line.append(' ')
-        text_line.append(f'Reference lengh: \t{self.ref_lenght} [m]')
-        text_line.append(f'Reference area: \t{self.ref_area} [m^2]')
+        text_line.append("\nAircraft data -------------------------------------------------------")
+        text_line.append(" ")
+        text_line.append(f"Reference lengh: \t{self.ref_lenght} [m]")
+        text_line.append(f"Reference area: \t{self.ref_area} [m^2]")
         text_line.append(
-            f'Reference point: \t({self.ref_point_x},{self.ref_point_y},{self.ref_point_z}) [m]')
-        text_line.append(' ')
-        text_line.append(f'Reference wing index: \t{self._ref_wing_idx}')
-        text_line.append(f'Wing span: \t\t{self.wing_span} [m]')
-        text_line.append(f'Wing area: \t\t{self.wing_area} [m^2]')
-        text_line.append(f'Wing AR: \t\t{self.wing_ar} [-]')
-        text_line.append(' ')
-        text_line.append('---------------------------------------------------------------------\n')
-        return ('\n').join(text_line)
+            f"Reference point: \t({self.ref_point_x},{self.ref_point_y},{self.ref_point_z}) [m]"
+        )
+        text_line.append(" ")
+        text_line.append(f"Reference wing index: \t{self._ref_wing_idx}")
+        text_line.append(f"Wing span: \t\t{self.wing_span} [m]")
+        text_line.append(f"Wing area: \t\t{self.wing_area} [m^2]")
+        text_line.append(f"Wing AR: \t\t{self.wing_ar} [-]")
+        text_line.append(" ")
+        text_line.append("---------------------------------------------------------------------\n")
+        return ("\n").join(text_line)
