@@ -22,20 +22,44 @@ Author: Aidan Jungo
 
 """
 
+from pathlib import Path
+
+
+# PATH
+CPACSPY_LIB = Path(__file__).absolute().parent
+CPACSPY_ROOT = CPACSPY_LIB.parents[1]
+EXAMPLES_PATH = Path(CPACSPY_ROOT, "examples")
+TESTS_PATH = Path(CPACSPY_ROOT, "tests")
+D150_TESTS_PATH = str(Path(TESTS_PATH, "D150_simple.xml"))
+
 # XPATH
-AEROPERFORMANCE_XPATH = '/cpacs/vehicles/aircraft/model/analyses/aeroPerformance'
-REF_XPATH = '/cpacs/vehicles/aircraft/model/reference'
+AEROPERFORMANCE_XPATH = "/cpacs/vehicles/aircraft/model/analyses/aeroPerformance"
+REF_XPATH = "/cpacs/vehicles/aircraft/model/reference"
 
 # Lists
-PARAMS = ['altitude', 'machNumber', 'angleOfSideslip', 'angleOfAttack']
-COEFS = ['cd', 'cl', 'cs', 'cmd', 'cml', 'cms']
+PARAMS = ["altitude", "machNumber", "angleOfSideslip", "angleOfAttack"]
+COEFS = ["cd", "cl", "cs", "cmd", "cml", "cms"]
 PARAMS_COEFS = PARAMS + COEFS
-DAMPING_COEFS = ['dcddpStar', 'dcddqStar', 'dcddrStar',
-                 'dcldpStar', 'dcldqStar', 'dcldrStar',
-                 'dcmddpStar', 'dcmddqStar', 'dcmddrStar',
-                 'dcmldpStar', 'dcmldqStar', 'dcmldrStar',
-                 'dcmsdpStar', 'dcmsdqStar', 'dcmsdrStar',
-                 'dcsdpStar', 'dcsdqStar', 'dcsdrStar']
+DAMPING_COEFS = [
+    "dcddpStar",
+    "dcddqStar",
+    "dcddrStar",
+    "dcldpStar",
+    "dcldqStar",
+    "dcldrStar",
+    "dcmddpStar",
+    "dcmddqStar",
+    "dcmddrStar",
+    "dcmldpStar",
+    "dcmldqStar",
+    "dcmldrStar",
+    "dcmsdpStar",
+    "dcmsdqStar",
+    "dcmsdrStar",
+    "dcsdpStar",
+    "dcsdqStar",
+    "dcsdrStar",
+]
 
 
 def listify(value):
